@@ -69,10 +69,16 @@ struct Layout
       return instanceDataStepRate < o.instanceDataStepRate;
     return false;
   }
-  DOCUMENT("The semantic name for this input.");
+  DOCUMENT(R"(The semantic name for this input.
+
+:type: str
+)");
   rdcstr semanticName;
 
-  DOCUMENT("The semantic index for this input.");
+  DOCUMENT(R"(The semantic index for this input.
+
+:type: int
+)");
   uint32_t semanticIndex = 0;
 
   DOCUMENT(R"(The format describing how the input data is interpreted.
@@ -81,7 +87,10 @@ struct Layout
 )");
   ResourceFormat format;
 
-  DOCUMENT("The vertex buffer input slot where the data is sourced from.");
+  DOCUMENT(R"(The vertex buffer input slot where the data is sourced from.
+
+:type: int
+)");
   uint32_t inputSlot = 0;
 
   DOCUMENT(R"(The byte offset from the start of the vertex data in the vertex buffer from
@@ -89,10 +98,15 @@ struct Layout
 
 If the value is :data:`TightlyPacked` then the element is packed tightly after the previous element, or 0
 if this is the first element.
+
+:type: int
 )");
   uint32_t byteOffset = 0;
 
-  DOCUMENT("``True`` if the vertex data is instance-rate.");
+  DOCUMENT(R"(``True`` if the vertex data is instance-rate.
+
+:type: bool
+)");
   bool perInstance = false;
 
   DOCUMENT(R"(If :data:`perInstance` is ``True`` then this is how many times each instance data is
@@ -100,6 +114,8 @@ used before advancing to the next instance.
 
 E.g. if this value is two, then two instances will be drawn with the first instance data, then two
 with the next instance data.
+
+:type: int
 )");
   uint32_t instanceDataStepRate = 0;
 
@@ -129,13 +145,22 @@ struct VertexBuffer
       return byteOffset < o.byteOffset;
     return false;
   }
-  DOCUMENT("The :class:`ResourceId` of the buffer bound to this slot.");
+  DOCUMENT(R"(The :class:`ResourceId` of the buffer bound to this slot.
+
+:type: ResourceId
+)");
   ResourceId resourceId;
 
-  DOCUMENT("The byte offset from the start of the buffer to the beginning of the vertex data.");
+  DOCUMENT(R"(The byte offset from the start of the buffer to the beginning of the vertex data.
+
+:type: int
+)");
   uint32_t byteOffset = 0;
 
-  DOCUMENT("The byte stride between the start of one set of vertex data and the next.");
+  DOCUMENT(R"(The byte stride between the start of one set of vertex data and the next.
+
+:type: int
+)");
   uint32_t byteStride = 0;
 };
 
@@ -147,14 +172,22 @@ struct IndexBuffer
   IndexBuffer(const IndexBuffer &) = default;
   IndexBuffer &operator=(const IndexBuffer &) = default;
 
-  DOCUMENT("The :class:`ResourceId` of the index buffer.");
+  DOCUMENT(R"(The :class:`ResourceId` of the index buffer.
+
+:type: ResourceId
+)");
   ResourceId resourceId;
 
-  DOCUMENT("The byte offset from the start of the buffer to the beginning of the index data.");
+  DOCUMENT(R"(The byte offset from the start of the buffer to the beginning of the index data.
+
+:type: int
+)");
   uint32_t byteOffset = 0;
 
   DOCUMENT(R"(The number of bytes for each index in the index buffer. Typically 2 or 4 bytes but
 it can be 0 if no index buffer is bound.
+
+:type: int
 )");
   uint32_t byteStride = 0;
 };
@@ -173,14 +206,17 @@ struct InputAssembly
 )");
   rdcarray<Layout> layouts;
 
-  DOCUMENT("The :class:`ResourceId` of the layout object.");
+  DOCUMENT(R"(The :class:`ResourceId` of the layout object.
+
+:type: ResourceId
+)");
   ResourceId resourceId;
 
   DOCUMENT(R"(The shader reflection for the bytecode used to create the input layout.
 
 :type: ShaderReflection
 )");
-  ShaderReflection *bytecode = NULL;
+  const ShaderReflection *bytecode = NULL;
 
   DOCUMENT(R"(The bound vertex buffers
 
@@ -209,16 +245,22 @@ struct Shader
   Shader(const Shader &) = default;
   Shader &operator=(const Shader &) = default;
 
-  DOCUMENT("The :class:`ResourceId` of the shader itself.");
+  DOCUMENT(R"(The :class:`ResourceId` of the shader itself.
+
+:type: ResourceId
+)");
   ResourceId resourceId;
 
   DOCUMENT(R"(The reflection data for this shader.
 
 :type: ShaderReflection
 )");
-  ShaderReflection *reflection = NULL;
+  const ShaderReflection *reflection = NULL;
 
-  DOCUMENT("A :class:`ShaderStage` identifying which stage this shader is bound to.");
+  DOCUMENT(R"(A :class:`ShaderStage` identifying which stage this shader is bound to.
+
+:type: ShaderStage
+)");
   ShaderStage stage = ShaderStage::Vertex;
 
   DOCUMENT(R"(The bound class instance names.
@@ -248,10 +290,16 @@ struct StreamOutBind
       return byteOffset < o.byteOffset;
     return false;
   }
-  DOCUMENT("The :class:`ResourceId` of the buffer.");
+  DOCUMENT(R"(The :class:`ResourceId` of the buffer.
+
+:type: ResourceId
+)");
   ResourceId resourceId;
 
-  DOCUMENT("The byte offset of the stream-output binding.");
+  DOCUMENT(R"(The byte offset of the stream-output binding.
+
+:type: int
+)");
   uint32_t byteOffset = 0;
 };
 
@@ -294,39 +342,73 @@ struct RasterizerState
   RasterizerState(const RasterizerState &) = default;
   RasterizerState &operator=(const RasterizerState &) = default;
 
-  DOCUMENT("The :class:`ResourceId` of the rasterizer state object.");
+  DOCUMENT(R"(The :class:`ResourceId` of the rasterizer state object.
+
+:type: ResourceId
+)");
   ResourceId resourceId;
-  DOCUMENT("The polygon :class:`FillMode`.");
+  DOCUMENT(R"(The polygon :class:`FillMode`.
+
+:type: FillMode
+)");
   FillMode fillMode = FillMode::Solid;
-  DOCUMENT("The polygon :class:`CullMode`.");
+  DOCUMENT(R"(The polygon :class:`CullMode`.
+
+:type: CullMode
+)");
   CullMode cullMode = CullMode::NoCull;
   DOCUMENT(R"(``True`` if counter-clockwise polygons are front-facing.
 ``False`` if clockwise polygons are front-facing.
+
+:type: bool
 )");
   bool frontCCW = false;
-  DOCUMENT("The fixed depth bias value to apply to z-values.");
+  DOCUMENT(R"(The fixed depth bias value to apply to z-values.
+
+:type: int
+)");
   int32_t depthBias = 0;
   DOCUMENT(R"(The clamp value for calculated depth bias from :data:`depthBias` and
 :data:`slopeScaledDepthBias`
+
+:type: float
 )");
   float depthBiasClamp = 0.0f;
-  DOCUMENT("The slope-scaled depth bias value to apply to z-values.");
+  DOCUMENT(R"(The slope-scaled depth bias value to apply to z-values.
+
+:type: float
+)");
   float slopeScaledDepthBias = 0.0f;
-  DOCUMENT("``True`` if pixels outside of the near and far depth planes should be clipped.");
+  DOCUMENT(R"(``True`` if pixels outside of the near and far depth planes should be clipped.
+
+:type: bool
+)");
   bool depthClip = false;
-  DOCUMENT("``True`` if the scissor test should be applied.");
+  DOCUMENT(R"(``True`` if the scissor test should be applied.
+
+:type: bool
+)");
   bool scissorEnable = false;
-  DOCUMENT("``True`` if the quadrilateral MSAA algorithm should be used on MSAA targets.");
+  DOCUMENT(R"(``True`` if the quadrilateral MSAA algorithm should be used on MSAA targets.
+
+:type: bool
+)");
   bool multisampleEnable = false;
-  DOCUMENT(
-      "``True`` if lines should be anti-aliased. Ignored if :data:`multisampleEnable` is "
-      "``False``.");
+  DOCUMENT(R"(``True`` if lines should be anti-aliased. Ignored if :data:`multisampleEnable` is  ``False``.
+
+:type: bool
+)");
   bool antialiasedLines = false;
   DOCUMENT(R"(A sample count to force rasterization to when UAV rendering or rasterizing, or 0 to
 not force any sample count.
+
+:type: int
 )");
   uint32_t forcedSampleCount = 0;
-  DOCUMENT("The current :class:`ConservativeRaster` mode.");
+  DOCUMENT(R"(The current :class:`ConservativeRaster` mode.
+
+:type: ConservativeRaster
+)");
   ConservativeRaster conservativeRasterization = ConservativeRaster::Disabled;
 };
 
@@ -365,15 +447,30 @@ struct DepthStencilState
   DepthStencilState(const DepthStencilState &) = default;
   DepthStencilState &operator=(const DepthStencilState &) = default;
 
-  DOCUMENT("The :class:`ResourceId` of the depth-stencil state object.");
+  DOCUMENT(R"(The :class:`ResourceId` of the depth-stencil state object.
+
+:type: ResourceId
+)");
   ResourceId resourceId;
-  DOCUMENT("``True`` if depth testing should be performed.");
+  DOCUMENT(R"(``True`` if depth testing should be performed.
+
+:type: bool
+)");
   bool depthEnable = false;
-  DOCUMENT("The :class:`CompareFunction` to use for testing depth values.");
+  DOCUMENT(R"(The :class:`CompareFunction` to use for testing depth values.
+
+:type: CompareFunction
+)");
   CompareFunction depthFunction = CompareFunction::AlwaysTrue;
-  DOCUMENT("``True`` if depth values should be written to the depth target.");
+  DOCUMENT(R"(``True`` if depth values should be written to the depth target.
+
+:type: bool
+)");
   bool depthWrites = false;
-  DOCUMENT("``True`` if stencil operations should be performed.");
+  DOCUMENT(R"(``True`` if stencil operations should be performed.
+
+:type: bool
+)");
   bool stencilEnable = false;
 
   DOCUMENT(R"(The stencil state for front-facing polygons.
@@ -397,14 +494,22 @@ struct BlendState
   BlendState(const BlendState &) = default;
   BlendState &operator=(const BlendState &) = default;
 
-  DOCUMENT("The :class:`ResourceId` of the blend state object.");
+  DOCUMENT(R"(The :class:`ResourceId` of the blend state object.
+
+:type: ResourceId
+)");
   ResourceId resourceId;
 
-  DOCUMENT("``True`` if alpha-to-coverage should be used when blending to an MSAA target.");
+  DOCUMENT(R"(``True`` if alpha-to-coverage should be used when blending to an MSAA target.
+
+:type: bool
+)");
   bool alphaToCoverage = false;
   DOCUMENT(R"(``True`` if independent blending for each target should be used.
 
 ``False`` if the first blend should be applied to all targets.
+
+:type: bool
 )");
   bool independentBlend = false;
 
@@ -419,7 +524,10 @@ struct BlendState
 :type: Tuple[float,float,float,float]
 )");
   rdcfixedarray<float, 4> blendFactor = {1.0f, 1.0f, 1.0f, 1.0f};
-  DOCUMENT("The mask determining which samples are written to.");
+  DOCUMENT(R"(The mask determining which samples are written to.
+
+:type: int
+)");
   uint32_t sampleMask = ~0U;
 };
 
@@ -449,7 +557,10 @@ struct OutputMerger
 )");
   rdcarray<Descriptor> renderTargets;
 
-  DOCUMENT("Which slot in the output targets is the first UAV.");
+  DOCUMENT(R"(Which slot in the output targets is the first UAV.
+
+:type: int
+)");
   uint32_t uavStartSlot = 0;
 
   DOCUMENT(R"(The currently bound depth-stencil target.
@@ -457,9 +568,15 @@ struct OutputMerger
 :type: Descriptor
 )");
   Descriptor depthTarget;
-  DOCUMENT("``True`` if depth access to the depth-stencil target is read-only.");
+  DOCUMENT(R"(``True`` if depth access to the depth-stencil target is read-only.
+
+:type: bool
+)");
   bool depthReadOnly = false;
-  DOCUMENT("``True`` if stencil access to the depth-stencil target is read-only.");
+  DOCUMENT(R"(``True`` if stencil access to the depth-stencil target is read-only.
+
+:type: bool
+)");
   bool stencilReadOnly = false;
 };
 
@@ -471,13 +588,22 @@ struct Predication
   Predication(const Predication &) = default;
   Predication &operator=(const Predication &) = default;
 
-  DOCUMENT("The :class:`ResourceId` of the active predicate.");
+  DOCUMENT(R"(The :class:`ResourceId` of the active predicate.
+
+:type: ResourceId
+)");
   ResourceId resourceId;
 
-  DOCUMENT("The value to go along with the predicate.");
+  DOCUMENT(R"(The value to go along with the predicate.
+
+:type: bool
+)");
   bool value = false;
 
-  DOCUMENT("``True`` if the current predicate would render.");
+  DOCUMENT(R"(``True`` if the current predicate would render.
+
+:type: bool
+)");
   bool isPassing = false;
 };
 
